@@ -7,7 +7,7 @@ from .blueprint import Blueprint  # noqa
 from .pagination import Page  # noqa
 from .error_handler import ErrorHandlerMixin
 
-__version__ = '0.27.0'
+__version__ = '0.28.0'
 
 
 class Api(APISpecMixin, ErrorHandlerMixin):
@@ -70,9 +70,6 @@ class Api(APISpecMixin, ErrorHandlerMixin):
         # Register error handlers
         self._register_error_handlers()
 
-        # Register responses
-        self._register_responses()
-
     def register_blueprint(self, blp, **options):
         """Register a blueprint in the application
 
@@ -87,7 +84,7 @@ class Api(APISpecMixin, ErrorHandlerMixin):
         self._app.register_blueprint(blp, **options)
 
         # Register views in API documentation for this resource
-        blp.register_views_in_doc(self._app, self.spec)
+        blp.register_views_in_doc(self, self._app, self.spec)
 
         # Add tag relative to this resource to the global tag list
         self.spec.tag({'name': blp.name, 'description': blp.description})
