@@ -14,8 +14,7 @@ from flask.views import MethodView
 from flask_smorest import Api, Blueprint, Page
 from flask_smorest.fields import Upload
 
-
-from .utils import build_ref
+from .utils import build_ref, get_responses
 
 
 LOCATIONS_MAPPING = (
@@ -396,6 +395,7 @@ class TestBlueprint:
             spec['paths']['/test/']['get']['responses'][str(error_code)] ==
             build_ref(api.spec, 'response', http.HTTPStatus(error_code).name)
         )
+        assert http.HTTPStatus(error_code).name in get_responses(api.spec)
 
     @pytest.mark.parametrize('openapi_version', ('2.0', '3.0.2'))
     def test_blueprint_route_parameters(self, app, openapi_version):
@@ -621,21 +621,36 @@ class TestBlueprint:
         get = api.spec.to_dict()['paths']['/test/']['get']
         assert get['responses']['200']['headers'] == headers
 
-    def test_blueprint_response_documents_default_error_response(self, app):
-        api = Api(app)
+    @pytest.mark.parametrize('default_error', ('default', 'override', 'None'))
+    def test_blueprint_documents_default_error_response(
+            self, app, default_error
+    ):
+        class MyApi(Api):
+            if default_error == "override":
+                DEFAULT_ERROR_RESPONSE_NAME = "MY_DEFAULT_ERROR"
+            elif default_error == "None":
+                DEFAULT_ERROR_RESPONSE_NAME = None
+
+        api = MyApi(app)
         blp = Blueprint('test', 'test', url_prefix='/test')
 
         @blp.route('/')
-        @blp.response()
         def func():
             pass
 
         api.register_blueprint(blp)
 
         get = api.spec.to_dict()['paths']['/test/']['get']
-        assert get['responses']['default'] == build_ref(
-            api.spec, 'response', 'DEFAULT_ERROR'
-        )
+        if default_error == "None":
+            assert "responses" not in get
+        else:
+            error_response = {
+                "default": "DEFAULT_ERROR",
+                "override": "MY_DEFAULT_ERROR",
+            }[default_error]
+            assert get['responses']['default'] == build_ref(
+                api.spec, 'response', error_response
+            )
 
     @pytest.mark.parametrize('openapi_version', ('2.0', '3.0.2'))
     def test_blueprint_pagination(self, app, schemas, openapi_version):
